==> glpi-11.0.2.tgz: glpi/src/Glpi/Application/View/Extension/TeamExtension.php <==
<?php

/**
 * ---------------------------------------------------------------------
 *
 * GLPI - Gestionnaire Libre de Parc Informatique
 *
 * http://glpi-project.org
 *
 * @copyright 2015-2025 Teclib' and contributors.
 * @copyright 2003-2014 by the INDEPNET Development Team.
 * @licence   https://www.gnu.org/licenses/gpl-3.0.html
 *
 * ---------------------------------------------------------------------
 *
 * LICENSE
 *
 * This file is part of GLPI.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * ---------------------------------------------------------------------
 */

namespace Glpi\Application\View\Extension;

use Glpi\Features\TeamworkInterface;
use Twig\Extension\AbstractExtension;
use Twig\TwigFilter;

/**
 * @since 10.0.0
 */
class TeamExtension extends AbstractExtension
{
    public function getFilters(): array
    {
        return [
            new TwigFilter('team_role_name', [$this, 'getTeamRoleName']),
        ];
    }

    public function getTeamRoleName($itemtype, int $role, int $nb = 1): string
    {
        if (is_a($itemtype, TeamworkInterface::class, true)) {
            return $itemtype::getTeamRoleName($role, $nb);
        }
        return '';
    }
}

==> glpi-11.0.3.tgz: glpi/src/Glpi/Application/View/Extension/TeamExtension.php <==
<?php

/**
 * ---------------------------------------------------------------------
 *
 * GLPI - Gestionnaire Libre de Parc Informatique
 *
 * http://glpi-project.org
 *
 * @copyright 2015-2025 Teclib' and contributors.
 * @copyright 2003-2014 by the INDEPNET Development Team.
 * @licence   https://www.gnu.org/licenses/gpl-3.0.html
 *
 * ---------------------------------------------------------------------
 *
 * LICENSE
 *
 * This file is part of GLPI.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * ---------------------------------------------------------------------
 */

namespace Glpi\Application\View\Extension;

use CommonDBTM;
use Glpi\Features\TeamworkInterface;
use Twig\Extension\AbstractExtension;
use Twig\TwigFilter;

/**
 * @since 10.0.0
 */
class TeamExtension extends AbstractExtension
{
    public function getFilters(): array
    {
        return [
            new TwigFilter('team_role_name', [$this, 'getTeamRoleName']),
        ];
    }

    /**
     * @param class-string<CommonDBTM> $itemtype
     * @param int $role
     * @param int $nb
     *
     * @return string
     */
    public function getTeamRoleName($itemtype, int $role, int $nb = 1): string
    {
        if (is_a($itemtype, TeamworkInterface::class, true)) {
            return $itemtype::getTeamRoleName($role, $nb);
        }
        return '';
    }
}
